@@ -1,5 +1,5 @@
 seqedist<-function(seqe, idcost, vparam, interval=TRUE, norm=TRUE){
     norm<-as.integer(norm)
     interval<-as.integer(interval)
-    return(.Call("tmrseqedist", seqe, idcost,vparam,norm, interval));
+    return(.Call(TMR_tmrseqedist, seqe, idcost, vparam, norm, interval));
 }
\ No newline at end of file
